02. Uniforms and Attributes
***************************

.. figure:: images/02_uniforms_and_attributes.png
	:scale: 50 %
	:alt: 02_uniforms_and_attributes
	:align: center
	:figclass: align-center

	Uniforms and Attributes

.. literalinclude:: ../../examples/GLWindow/02_uniforms_and_attributes.py
	:linenos:
